/* File System Lib
 *
 * Mini File System
 *
 * Copyright (C) 2001-2003 Pu Bo
 * Copyright (C) 2003 Wang Zheng
 */
#ifndef _FILESYS_H
#define _FILESYS_H

#ifndef WIN32
#include "MFS.h"
#endif

#ifdef WIN32
#include "FileSysIfc.h"
#include "CasioTyp.h"
#include "MemMgr.h"

inline FileHndl FileOpen(const char far *name,FileOpenMode mode) {
	FileHndl file;
	switch(mode) {
	case kFSReadOnly:
		file = fopen(name,"rb");
		break;
	case kFSWriteOnly:
		file = fopen(name,"wb");
		break;
	case kFSReadWrite:
		file = fopen(name,"r+b");
		break;
	}
	return ((FileHndl)file);
}

inline unsigned long FileRead(FileHndl fileH,MemHndl bufH,unsigned long size) {
	return (fread(*bufH,1,size,fileH));
}

inline unsigned long FileWrite(FileHndl fileH,MemHndl bufH,unsigned long size) {
	return (fwrite(*bufH,1,size,fileH));
}

inline FSErr FileSeek(FileHndl fileH,unsigned long pos) {
	if (fseek(fileH,pos,SEEK_SET) == 0) {
		return (kFSNoErr);
	}
	else {
		return (kFSErrSeekFile);
	}
}

inline unsigned long FileTell(FileHndl fileH) {
	return (ftell(fileH));
}

inline unsigned long GetFileSize(FileHndl fileH) {
	unsigned long curPos = ftell(fileH);
	fseek(fileH,0,SEEK_END);
	unsigned long size = ftell(fileH);
	fseek(fileH,curPos,SEEK_SET);
	return (size);
}

inline void FileClose(FileHndl fileH) {
	fclose(fileH);
}
#else
#define MFS_ROOT "MFSROOT"

typedef bool (*FileMgmtProgressCBFunc)(unsigned long maxVal, unsigned long curVal);

FSErr ChangeCurDir(const char far *pathName);
unsigned short GetDirFileNumber(FileHndl dir);
void GetFileName(FileHndl dir,unsigned short fileIdx,char far *fileName);
bool IsDir(FileHndl dir,unsigned short fileIdx);
bool IsFileDir(FileHndl fileH);
FileHndl MakeDir(const char far *name);
FileHndl FileOpen(const char far *name,FileOpenMode mode);
unsigned long FileRead(FileHndl fileH,MemHndl bufH,unsigned long size);
unsigned long FileWrite(FileHndl fileH,MemHndl bufH,unsigned long size);
FSErr FileSeek(FileHndl fileH,unsigned long pos);
unsigned long FileTell(FileHndl fileH);
unsigned long GetFileSize(FileHndl fileH);
void FileClose(FileHndl fileH);
FSErr DeleteFile(const char far *pathName);
FSErr GetLastError();
const char far *GetCurrentDirectory();
void FileSysManagement();
void TrimFile(FileHndl fileH);
FSErr FileRename(const char far *srcPath,const char far *destPath);
void FileSysSetMgmtProgressCB(FileMgmtProgressCBFunc cb);
unsigned long FileSysAvailableStorage();
#endif

#endif